@@ -228,13 +228,16 @@ def telescopes(state, organisation=None):
         click.echo(" • Fetching telescopes...")
 
     telescope_list, error = ArcsecondAPI.telescopes(**kwargs).list()
-    if error:
+    if error is not None:
         raise OortCloudError(str(error))
 
     click.echo(f" • Found {len(telescope_list)} telescope{'s' if len(telescope_list) > 1 else ''}.")
     for telescope_dict in telescope_list:
-        s = f" 🔭 \"{telescope_dict['name']}\" (UUID: {telescope_dict['uuid']}) "
-        s += f"[ObservingSite UUID: {telescope_dict['observing_site']}]"
+        s = f" >>> 🔭 \"{telescope_dict['name']}\" "
+        if telescope_dict['alias']:
+            s += f"alias \"{telescope_dict['alias']}\" "
+        s += f"({telescope_dict['uuid']}) "
+        # s += f"[ObservingSite UUID: {telescope_dict['observing_site']}]"
         click.echo(s)
 
 
@@ -244,8 +247,8 @@ def telescopes(state, organisation=None):
               required=False, nargs=1,
               help="The Organisation subdomain, if uploading to an organisation.")
 @click.option('-t', '--telescope',
-              required=False, nargs=1, type=click.UUID,
-              help="The UUID of the telescope acquiring data (in the case of organisation uploads).")
+              required=False, nargs=1, type=click.STRING,
+              help="The UUID or the alias of the telescope acquiring data (in the case of organisation uploads).")
 @click.option('-z', '--zip',
               required=False, nargs=1, type=click.BOOL,
               help="Zip the data files (FITS and XISF) before sending to the cloud. Default is False.")
@@ -284,8 +287,11 @@ def watch(state, folders, organisation=None, telescope=None, zip=False):
         click.echo(f" • Uploading to organisation account '{org_subdomain}' (as {org_role}).")
 
     if telescope_details:
-        name, uuid = telescope_details.get('name'), telescope_details.get('uuid')
-        click.echo(f" • Night Logs will be linked to telescope '{name}' ({uuid}).")
+        msg = f" • Night Logs will be linked to telescope '{telescope_details.get('name')}' "
+        if telescope_details.get('alias', ''):
+            msg += f"alias \"{telescope_details.get('alias')}\" "
+        msg += f"({telescope_details.get('uuid')}))"
+        click.echo(msg)
     else:
         click.echo(" • No designated telescope.")
 
@@ -295,9 +301,7 @@ def watch(state, folders, organisation=None, telescope=None, zip=False):
     click.echo(f" • Folder path{'s' if len(folders) > 1 else ''}:")
     for folder in folders:
         folder_path = pathlib.Path(folder).expanduser().resolve()
-        if folder_path.is_file():
-            folder_path = folder_path.parent
-        click.echo(f"   > {str(folder_path)}")
+        click.echo(f"   > {str(folder_path.parent if folder_path.is_file() else folder_path)}")
         if folder_path == home_path:
             click.echo("   >>> Warning: This watched folder is your HOME folder. <<<")
         if str(folder_path) in existing_folders:
@@ -317,7 +321,7 @@ def watch(state, folders, organisation=None, telescope=None, zip=False):
                             state.verbose)
 
         click.echo("\n • OK.")
-        msg = f" • Watch will start within {OORT_UPLOADER_FOLDER_DETECTION_TICK_SECONDS} seconds "
-        msg += "if the uploader process is running.\n • Getting processes status for you right now:"
+        msg = f" • Oort will start watching within {OORT_UPLOADER_FOLDER_DETECTION_TICK_SECONDS} seconds "
+        msg += "if the uploader process is running.\n • Getting the processes status for you right now:"
         click.echo(msg)
         get_supervisor_processes_status(debug=state.debug)
