@@ -18,9 +18,7 @@ from oort.shared.config import get_oort_logger
 from oort.shared.constants import ZIP_EXTENSIONS, get_all_fits_extensions, get_all_xisf_extensions
 from oort.shared.identity import Identity
 from oort.shared.models import (
-    Calibration,
     FINISHED_SUBSTATUSES,
-    Observation,
     PREPARATION_DONE_SUBSTATUSES,
     Status,
     Substatus,
@@ -76,12 +74,12 @@ class UploadPack(object):
         except Upload.DoesNotExist:
             self._upload = Upload.create(file_path=self.clear_file_path)
 
-        self.update_upload(astronomer=self._identity.username,
-                           file_path_zipped=self.zipped_file_path)
+        self.upload.smart_update(astronomer=self._identity.username,
+                                 file_path_zipped=self.zipped_file_path)
 
         self._find_date_size_and_target_name()
 
-    def do_upload(self):
+    def prepare_and_upload_file(self):
         if self.should_zip:
             zip = zipper.AsyncZipper(self.clear_file_path)
             zip.start()
@@ -104,7 +102,7 @@ class UploadPack(object):
 
         if self.should_prepare:
             upload_preparator = preparator.UploadPreparator(self, debug=self._identity.debug)
-            preparation_succeeded, _ = upload_preparator.prepare()
+            preparation_succeeded = upload_preparator.prepare()
         else:
             self._logger.info(f'{self.log_prefix} Preparation already done for {item}.')
 
@@ -113,7 +111,7 @@ class UploadPack(object):
                 self._logger.info(f'{self.log_prefix} Upload already finished for {item}.')
             else:
                 file_uploader = uploader.FileUploader(self)
-                file_uploader.upload()
+                file_uploader.upload_file()
 
     @property
     def log_prefix(self) -> str:
@@ -188,9 +186,9 @@ class UploadPack(object):
         x = 0 if self._upload.file_date.hour >= 12 else 1
         return (self._upload.file_date - timedelta(days=x)).date().isoformat()
 
-    @property
-    def resource_db_class(self):
-        return Observation if self._type == ResourceType.OBSERVATION else Calibration
+    # @property
+    # def resource_db_class(self):
+    #     return Observation if self._type == ResourceType.OBSERVATION else Calibration
 
     @property
     def remote_resources_name(self) -> str:
@@ -204,6 +202,14 @@ class UploadPack(object):
     def dataset_name(self) -> str:
         return self._dataset_name.strip()
 
+    @property
+    def clean_folder_name(self) -> str:
+        return self._clean_folder_name.strip()
+
+    @property
+    def root_folder_name(self) -> str:
+        return str(self._root_path)
+
     @property
     def target_name(self) -> str:
         return self._upload.target_name.strip()
@@ -217,23 +223,19 @@ class UploadPack(object):
         return self._upload.status == Status.OK.value and self._upload.substatus in FINISHED_SUBSTATUSES
 
     def _parse_type_and_dataset_name(self):
-        # No starting root, and no ending filename. Just the final folder.
-        _clean_path = self._raw_file_path.relative_to(self._root_path).parent
-        _is_calib = any([c for c in CALIB_PREFIXES if c in str(_clean_path).lower()])
-
+        # No ending filename. Just the final folder, including the root one! --------vvvvvv
+        self._clean_folder_name = str(self._raw_file_path.relative_to(self._root_path.parent).parent)
+        self._dataset_name = self._clean_folder_name
+        _is_calib = any([c for c in CALIB_PREFIXES if c in self._clean_folder_name.lower()])
         self._type = ResourceType.CALIBRATION if _is_calib else ResourceType.OBSERVATION
-        self._dataset_name = str(_clean_path)
-
-        if len(self._dataset_name.strip()) == 0 or self._dataset_name.strip() == '.':
-            self._dataset_name = f'(folder {self._root_path.name})'
 
     def _find_date_size_and_target_name(self) -> None:
         _file_date, _target_name = self._find_date_and_target_name()
         _file_size, _zipped_file_size = self._find_sizes()
-        self.update_upload(file_date=_file_date,
-                           file_size=_file_size,
-                           file_size_zipped=_zipped_file_size,
-                           target_name=_target_name or '')
+        self.upload.smart_update(file_date=_file_date,
+                                 file_size=_file_size,
+                                 file_size_zipped=_zipped_file_size,
+                                 target_name=_target_name or self._root_path.name or '')
 
     def _find_sizes(self) -> Tuple[float, float]:
         _file_size = 0
@@ -348,7 +350,4 @@ class UploadPack(object):
         return target_name
 
     def _archive(self, substatus) -> None:
-        self.update_upload(status=Status.OK.value, substatus=substatus, ended=datetime.now())
-
-    def update_upload(self, **kwargs) -> None:
-        self._upload = self._upload.smart_update(**kwargs)
+        self._upload = self._upload.archive(substatus=substatus, ended=datetime.now())
