@@ -1,10 +1,13 @@
 import json
 import os
+import pathlib
+import socket
 from datetime import datetime
 
 from arcsecond import ArcsecondAPI
 from arcsecond.api.endpoints import AsyncFileUploader
 
+from oort import __version__
 from oort.shared.config import get_oort_logger
 from oort.shared.models import Status, Substatus
 from . import errors
@@ -13,61 +16,69 @@ from . import errors
 class FileUploader(object):
     def __init__(self, pack):
         self._logger = get_oort_logger('uploader', debug=True)
+
         self._pack = pack
         self._upload = self._pack.upload
-        self._final_file_path = self._pack.final_file_path
-        self._dataset_uuid = self._upload.dataset.uuid
-        self._stalled_progress = 0
+        self._final_file_path = pathlib.Path(self._pack.final_file_path)
 
-        is_test_context = os.environ.get('OORT_TESTS') == '1'
-        self._api = ArcsecondAPI.datafiles(dataset=str(self._dataset_uuid),
-                                           debug=pack.identity.debug,
-                                           test=is_test_context,
+        is_test_context = bool(os.environ.get('OORT_TESTS') == '1')
+        self._api = ArcsecondAPI.datafiles(dataset=str(self._upload.dataset.uuid),  # will be used as request prefix
                                            upload_key=pack.identity.upload_key,
-                                           organisation=pack.identity.subdomain)
+                                           organisation=pack.identity.subdomain,
+                                           debug=pack.identity.debug,
+                                           test=is_test_context)
 
     @property
     def log_prefix(self) -> str:
-        return f'[FileUploader: {self._final_file_path}]'
-
-    def update_upload(self, **kwargs):
-        self._upload = self._upload.smart_update(**kwargs)
+        return f'[FileUploader: {str(self._final_file_path)}]'
 
     def _prepare_file_uploader(self, remote_resource_exists):
+        # Callback allowing for the server monitor to display the percentage of progress of the upload.
         def update_upload_progress(event, progress_percent):
             if progress_percent > self._upload.progress + 0.1 or progress_percent > 99:
-                self.update_upload(status=Status.UPLOADING.value,
-                                   substatus=Substatus.UPLOADING.value,
-                                   progress=progress_percent,
-                                   duration=(datetime.now() - self._upload.started).total_seconds())
+                self._upload.smart_update(status=Status.UPLOADING.value,
+                                          substatus=Substatus.UPLOADING.value,
+                                          progress=progress_percent,
+                                          duration=(datetime.now() - self._upload.started).total_seconds())
+
+        ffps = str(self._final_file_path)
+
+        tag_filepath = f'filepath|{ffps}'
+        tag_folder = f'folder|{self._pack.clean_folder_name}'
+        tag_root = f'root|{self._pack.root_folder_name}'
+        tag_origin = f'origin|{socket.gethostname()}|'
+        tag_uploader = f'uploader|{ArcsecondAPI.username()}'
+        tag_oort = f'oort|{__version__}'
+
+        payload = {'file': ffps, 'tags': [tag_filepath, tag_folder, tag_root, tag_origin, tag_uploader, tag_oort]}
 
         self._async_file_uploader: AsyncFileUploader
         if remote_resource_exists:
             self._logger.info(f"{self.log_prefix} Remote resource exists. Preparing 'Update' APIs.")
-            self._async_file_uploader, error = self._api.update(os.path.basename(self._final_file_path),
-                                                                {'file': self._final_file_path},
+            self._async_file_uploader, error = self._api.update(self._final_file_path.name, payload,
                                                                 callback=update_upload_progress)
         else:
             self._logger.info(f"{self.log_prefix} Remote resource does not exist. Preparing 'Create' APIs.")
-            self._async_file_uploader, error = self._api.create({'file': self._final_file_path},
-                                                                callback=update_upload_progress)
+            self._async_file_uploader, error = self._api.create(payload, callback=update_upload_progress)
 
-        if error:
-            self._logger.info(f'{self.log_prefix} API preparation error for {self._final_file_path}: {str(error)}')
+        if error is not None:
+            msg = f'{self.log_prefix} API preparation error for {ffps}: {str(error)}'
+            self._logger.error(msg)
 
     def _check_remote_resource_and_file(self):
         _remote_resource_exists = False
         _remote_resource_has_file = False
 
-        response, error = self._api.read(os.path.basename(self._final_file_path))
+        # self._api contains a reference to the dataset.
+        response, error = self._api.read(self._final_file_path.name)
 
-        if error:
+        if error is not None:
             if 'not found' in error.lower():
                 # Remote file resource doesn't exists remotely. self._api.create method is fine.
                 _remote_resource_exists = False
             else:
                 # If for some reason the resource is duplicated, we end up here.
-                self._logger.info(f'{self.log_prefix} Check remote file failed with error: {str(error)}')
+                self._logger.error(f'{self.log_prefix} Check remote file failed with error: {str(error)}')
                 raise errors.UploadRemoteFileCheckError(str(error))
         else:
             _remote_resource_exists = True
@@ -80,39 +91,30 @@ class FileUploader(object):
 
     def _check(self):
         _should_perform = False
-        self.update_upload(started=datetime.now())
+        self._upload.smart_update(started=datetime.now())
 
         try:
-            self.update_upload(status=Status.UPLOADING.value, substatus=Substatus.CHECKING.value)
+            self._upload.smart_update(status=Status.UPLOADING.value, substatus=Substatus.CHECKING.value)
             exists_remotely = self._check_remote_resource_and_file()
 
-        except errors.UploadRemoteFileCheckError as error:
-            self._logger.info(f'{self.log_prefix} {str(error)}')
-            self.update_upload(status=Status.ERROR.value,
-                               substatus=Substatus.ERROR.value,
-                               error=str(error),
-                               ended=datetime.now(),
-                               progress=0,
-                               duration=0)
-
-        except Exception as error:
-            self._logger.info(f'{self.log_prefix} {str(error)}')
-            self.update_upload(status=Status.ERROR.value,
-                               substatus=Substatus.ERROR.value,
-                               error=str(error),
-                               ended=datetime.now(),
-                               progress=0,
-                               duration=0)
+        except (errors.UploadRemoteFileCheckError, Exception) as error:
+            self._logger.error(f'{self.log_prefix} {str(error)}')
+            self._upload.smart_update(status=Status.ERROR.value,
+                                      substatus=Substatus.ERROR.value,
+                                      error=str(error),
+                                      ended=datetime.now(),
+                                      progress=0,
+                                      duration=0)
 
         else:
             if exists_remotely:
                 self._logger.info(f'{self.log_prefix} Already synced.')
-                self.update_upload(status=Status.OK.value,
-                                   substatus=Substatus.ALREADY_SYNCED.value,
-                                   error='',
-                                   ended=datetime.now(),
-                                   progress=0,
-                                   duration=0)
+                self._upload.smart_update(status=Status.OK.value,
+                                          substatus=Substatus.ALREADY_SYNCED.value,
+                                          error='',
+                                          ended=datetime.now(),
+                                          progress=0,
+                                          duration=0)
             else:
                 _should_perform = True
 
@@ -122,14 +124,14 @@ class FileUploader(object):
         if not self._check():
             return
 
-        self.update_upload(status=Status.UPLOADING.value, substatus=Substatus.STARTING.value, error='')
+        self._upload.smart_update(status=Status.UPLOADING.value, substatus=Substatus.STARTING.value, error='')
         self._logger.info(f'{self.log_prefix} Starting upload ({self._upload.get_formatted_size()})')
 
         self._async_file_uploader.start()
         _, upload_error = self._async_file_uploader.finish()
 
         ended = datetime.now()
-        self.update_upload(ended=ended, progress=0, duration=(ended - self._upload.started).total_seconds())
+        self._upload.smart_update(ended=ended, progress=0, duration=(ended - self._upload.started).total_seconds())
 
         if upload_error:
             self._logger.info(f'{self.log_prefix} {str(upload_error)}')
@@ -138,7 +140,7 @@ class FileUploader(object):
             msg = f'{self.log_prefix} Successfully uploaded {self._upload.get_formatted_size()}'
             msg += f' in {self._upload.duration} seconds.'
             self._logger.info(msg)
-            self.update_upload(status=Status.OK.value, substatus=Substatus.DONE.value, error='')
+            self._upload.smart_update(status=Status.OK.value, substatus=Substatus.DONE.value, error='')
 
     def _process_error(self, error):
         status, substatus, error = Status.ERROR.value, Substatus.ERROR.value, str(error)
@@ -154,9 +156,9 @@ class FileUploader(object):
                 if 'already exists in dataset' in error_content:
                     status, substatus, error = Status.OK.value, Substatus.ALREADY_SYNCED.value, ''
 
-        self.update_upload(status=status, substatus=substatus, error=error)
+        self._upload.smart_update(status=status, substatus=substatus, error=error)
 
-    def upload(self):
+    def upload_file(self):
         self._logger.info(f'{self.log_prefix} Opening upload sequence.')
         self._perform()
         self._logger.info(f'{self.log_prefix} Closing upload sequence.')
